@@ -39,9 +39,9 @@ QTEST_MAIN(KArchiveTest)
 
 static const int SIZE1 = 100;
 
-/**
+/*!
  * Writes test fileset specified archive
- * @param archive archive
+ * \a archive archive
  */
 static void writeTestFilesToArchive(KArchive *archive)
 {
@@ -160,9 +160,9 @@ static QStringList recursiveListEntries(const KArchiveDirectory *dir, const QStr
     return ret;
 }
 
-/**
+/*!
  * Verifies contents of specified archive against test fileset
- * @param archive archive
+ * \a archive archive
  */
 static void testFileData(KArchive *archive)
 {
@@ -329,7 +329,7 @@ static void testCopyTo(KArchive *archive)
     QVERIFY(QFileInfo(dirName + "executableAll").permissions() & (QFileDevice::ExeOwner | QFileDevice::ExeGroup | QFileDevice::ExeOther));
 }
 
-/**
+/*!
  * Prepares dataset for archive filter tests
  */
 void KArchiveTest::setupData()
@@ -346,6 +346,8 @@ void KArchiveTest::setupData()
 #if HAVE_XZ_SUPPORT
     QTest::newRow(".tar.lzma") << "karchivetest.tar.lzma"
                                << "application/x-lzma";
+    QTest::newRow(".tar.lz") << "karchivetest.tar.lz"
+                             << "application/x-lzip";
     QTest::newRow(".tar.xz") << "karchivetest.tar.xz"
                              << "application/x-xz";
 #endif
@@ -355,8 +357,8 @@ void KArchiveTest::setupData()
 #endif
 }
 
-/**
- * @see QTest::initTestCase()
+/*!
+ * \sa QTest::initTestCase()
  */
 void KArchiveTest::initTestCase()
 {
@@ -402,7 +404,7 @@ void KArchiveTest::testCreateTar_data()
     QTest::newRow(".tar") << "karchivetest.tar";
 }
 
-/**
+/*!
  * @dataProvider testCreateTar_data
  */
 void KArchiveTest::testCreateTar()
@@ -431,7 +433,7 @@ void KArchiveTest::testCreateTar()
     // QFile::remove(fileName);
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testCreateTarXXX()
@@ -473,7 +475,7 @@ void KArchiveTest::testCreateTarXXX()
         QVERIFY(dt.secsTo(expectedDateTime) <= 2);                                                                                                             \
     }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testReadTar() // testCreateTarGz must have been run first.
@@ -545,7 +547,7 @@ void KArchiveTest::testReadTar() // testCreateTarGz must have been run first.
     }
 }
 
-/**
+/*!
  * This tests the decompression using kfilterdev, basically.
  * To debug KTarPrivate::fillTempFile().
  *
@@ -577,7 +579,7 @@ void KArchiveTest::testUncompress()
     QVERIFY(totalSize > 26000); // 27648 here when using gunzip
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testTarFileData()
@@ -593,7 +595,7 @@ void KArchiveTest::testTarFileData()
     QVERIFY(tar.close());
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testTarCopyTo()
@@ -609,7 +611,7 @@ void KArchiveTest::testTarCopyTo()
     QVERIFY(tar.close());
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testTarReadWrite()
@@ -647,7 +649,7 @@ void KArchiveTest::testTarMaxLength_data()
     QTest::newRow("maxlength.tar.gz") << "karchivetest-maxlength.tar.gz";
 }
 
-/**
+/*!
  * @dataProvider testTarMaxLength_data
  */
 void KArchiveTest::testTarMaxLength()
@@ -1216,7 +1218,7 @@ void KArchiveTest::testZipReadRedundantDataDescriptor_data()
     QTest::newRow("withSignature") << "data/redundantDataDescriptorsWithSignature.zip";
 }
 
-/**
+/*!
  * @dataProvider testZipReadRedundantDataDescriptor_data
  */
 void KArchiveTest::testZipReadRedundantDataDescriptor()
@@ -1276,6 +1278,31 @@ void KArchiveTest::testZipWithinZip()
     QCOMPARE(listing[1], QString::fromUtf8("mode=100644 path=test.epub type=file size=525154"));
 }
 
+void KArchiveTest::testZipPrependedData()
+{
+    const QString fileName = QFINDTESTDATA("data/zip64_datadescriptor.zip");
+    QVERIFY(!fileName.isEmpty());
+
+    QFile origFile(fileName);
+    QVERIFY2(origFile.open(QIODevice::ReadOnly), qPrintable(origFile.errorString()));
+    auto zipData = origFile.readAll();
+    QVERIFY(zipData.startsWith("PK"));
+
+    zipData.insert(0, QByteArrayLiteral("PrependedPK\x01\x02Garbage"));
+    QBuffer zipBuffer(&zipData);
+
+    KZip zip(&zipBuffer);
+    QVERIFY2(zip.open(QIODevice::ReadOnly), qPrintable(zip.errorString()));
+
+    QCOMPARE(zip.directory()->entries().size(), 1);
+    QCOMPARE(zip.directory()->entries(), QList{QStringLiteral("-")});
+
+    auto entry = zip.directory()->file(QStringLiteral("-"));
+    QVERIFY(entry);
+    QCOMPARE(entry->size(), 4);
+    QCOMPARE(entry->data(), "abcd");
+}
+
 void KArchiveTest::testZipUnusualButValid()
 {
     const QString fileName = QFINDTESTDATA("data/unusual_but_valid_364071.zip");
@@ -1429,6 +1456,7 @@ void KArchiveTest::testZip64DataDescriptor()
     auto entry = zip.directory()->file(QStringLiteral("-"));
     QVERIFY(entry);
     QCOMPARE(entry->size(), 4);
+    QCOMPARE(entry->data(), "abcd");
 
     QVERIFY(zip.close());
 }
@@ -1539,8 +1567,8 @@ void KArchiveTest::testAr()
     QVERIFY(ar.close());
 }
 
-/**
- * @see QTest::cleanupTestCase()
+/*!
+ * \sa QTest::cleanupTestCase()
  */
 void KArchiveTest::cleanupTestCase()
 {
@@ -1556,7 +1584,7 @@ void KArchiveTest::cleanupTestCase()
 
 #if HAVE_XZ_SUPPORT
 
-/**
+/*
  * Prepares dataset for 7zip tests
  */
 void KArchiveTest::setup7ZipData()
@@ -1565,7 +1593,7 @@ void KArchiveTest::setup7ZipData()
     QTest::newRow(".7z") << "karchivetest.7z";
 }
 
-/**
+/*
  * @dataProvider testCreate7Zip_data
  */
 void KArchiveTest::testCreate7Zip()
@@ -1588,7 +1616,7 @@ void KArchiveTest::testCreate7Zip()
     }
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::testRead7Zip() // testCreate7Zip must have been run first.
@@ -1637,7 +1665,7 @@ void KArchiveTest::testRead7Zip() // testCreate7Zip must have been run first.
     }
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::test7ZipFileData()
@@ -1653,7 +1681,7 @@ void KArchiveTest::test7ZipFileData()
     QVERIFY(k7zip.close());
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::test7ZipCopyTo()
@@ -1669,7 +1697,7 @@ void KArchiveTest::test7ZipCopyTo()
     QVERIFY(k7zip.close());
 }
 
-/**
+/*!
  * @dataProvider setupData
  */
 void KArchiveTest::test7ZipReadWrite()
@@ -1701,7 +1729,7 @@ void KArchiveTest::test7ZipReadWrite()
     QFile::remove(fileName);
 }
 
-/**
+/*!
  * @dataProvider test7ZipMaxLength_data
  */
 void KArchiveTest::test7ZipMaxLength()
